@@ -1,4 +1,4 @@
-__version__=0.42
+__version__=0.44
 
 ### Load the FairDetect Class
 import time
@@ -147,7 +147,7 @@ class Fairdetect:
 
             fig.add_trace(go.Bar(
             showlegend=False,
-            x = [str(i)],
+            x = [target_names[i]],
             y= [labl_rep[str(i)]],
             marker_color=['orange','blue'][i]),row=1,col=2)
 
@@ -433,17 +433,17 @@ class Fairdetect:
         positive_outcomes_unfavoured = unfavoured_df[unfavoured_df['t'] ==1].shape[0]
         positive_ratio_unfavoured = positive_outcomes_unfavoured/num_of_unfavoured
                            
-        disparate_impact = positive_ratio_unfavoured / positive_ratio_favoured
-        print("Disparate Impact, Sensitive vs. Predicted Target: " + str(disparate_impact))
+        self.disparate_impact = positive_ratio_unfavoured / positive_ratio_favoured
+        print("Disparate Impact, Sensitive vs. Predicted Target: " + str(self.disparate_impact))
         
-        if disparate_impact <= 0.8:
+        if self.disparate_impact <= 0.8:
             print('\033[1;4m'+"The disparate impact ratio is below 0.8 indicating a favour towards the priviliged group"+'\033[0m')
-        elif disparate_impact <= 0.9:
+        elif self.disparate_impact <= 0.9:
             print("The disparate impact ratio indicates a slight favour towards the priviliged group")
         else: 
             print("The disparate impact ratio indicated complete equality between the favoured and unfavoured group")
             
-        plt.bar('Ratio',disparate_impact)
+        plt.bar('Ratio',self.disparate_impact)
         plt.title('Disparate impact')
         plt.xlabel('Ratio for postive outcomes for favoured and unfavoured groups')
         plt.ylabel('disparate_impact')
